ProcessIdentityPolicy

Enum ProcessIdentityPolicy 

pub enum ProcessIdentityPolicy {
    Auto,
    Fixed {
        hostname: Option<String>,
        pid: Option<u32>,
    },
    Resolver(Arc<dyn ProcessIdentityResolver>),
}
Policy describing how process identity is populated at runtime.

Variants



Auto

Resolve process identity automatically using the default runtime behavior.



Fixed

Use a fixed caller-supplied identity.

Fields

hostname: Option<String>

Fixed hostname value.

pid: Option<u32>

Fixed process identifier value.



Resolver(Arc<dyn ProcessIdentityResolver>)

Delegate identity resolution to a caller-supplied resolver.