ProcessIdentityResolver

Trait ProcessIdentityResolver 

pub trait ProcessIdentityResolver: Send + Sync {
    // Required method
    fn resolve(&self) -> Result<ProcessIdentity, IdentityError>;
}
Open resolver contract for caller-defined process identity lookup.

Required Methods

fn resolve(&self) -> Result<ProcessIdentity, IdentityError>

Resolves the process identity to attach to emitted records.

Errors

Returns IdentityError when the resolver cannot produce a valid process identity.

Implementors