pub enum ProcessIdentityPolicy {
Auto,
Fixed {
hostname: Option<String>,
pid: Option<u32>,
},
Resolver(Arc<dyn ProcessIdentityResolver>),
}Expand description
Policy describing how process identity is populated at runtime.
Variants
Auto
Resolve process identity automatically using the default runtime behavior.
Fixed
Use a fixed caller-supplied identity.
Fields
Resolver(Arc<dyn ProcessIdentityResolver>)
Delegate identity resolution to a caller-supplied resolver.