pub struct ErrorContext { /* private fields */ }Expand description
Builder-style context wrapper used by public crate error types.
Implementations
Sourceimpl ErrorContext
impl ErrorContext
Sourcepub fn new(
code: ErrorCode,
message: impl Into<String>,
remediation: Remediation,
) -> Self
pub fn new( code: ErrorCode, message: impl Into<String>, remediation: Remediation, ) -> Self
Creates a new error context with the required code, message, and remediation.
Sourcepub fn cause(self, cause: impl Into<String>) -> Self
pub fn cause(self, cause: impl Into<String>) -> Self
Adds a human-readable cause string to the error context.
Sourcepub fn docs(self, docs: impl Into<String>) -> Self
pub fn docs(self, docs: impl Into<String>) -> Self
Adds a documentation reference string to the error context.
Sourcepub fn detail(self, key: impl Into<String>, value: Value) -> Self
pub fn detail(self, key: impl Into<String>, value: Value) -> Self
Adds one structured detail field to the error context.
Sourcepub fn source(self, source: Box<dyn Error + Send + Sync + 'static>) -> Self
pub fn source(self, source: Box<dyn Error + Send + Sync + 'static>) -> Self
Captures the real source error for display and error chaining.
Sourcepub fn diagnostic(&self) -> &Diagnostic
pub fn diagnostic(&self) -> &Diagnostic
Returns the structured diagnostic carried by this error context.